Struct amazon_sp_sellers::models::marketplace::Marketplace
source · [−]pub struct Marketplace {
pub id: String,
pub name: String,
pub country_code: String,
pub default_currency_code: String,
pub default_language_code: String,
pub domain_name: String,
}Expand description
Marketplace : Detailed information about an Amazon market where a seller can list items for sale and customers can view and purchase items.
Fields
id: StringThe encrypted marketplace value.
name: StringMarketplace name.
country_code: StringThe ISO 3166-1 alpha-2 format country code of the marketplace.
default_currency_code: StringThe ISO 4217 format currency code of the marketplace.
default_language_code: StringThe ISO 639-1 format language code of the marketplace.
domain_name: StringThe domain name of the marketplace.
Implementations
sourceimpl Marketplace
impl Marketplace